summaryrefslogtreecommitdiffstats
path: root/src/DotNetOpenAuth.AspNet/Clients/OAuth2/MicrosoftClient.cs
diff options
context:
space:
mode:
Diffstat (limited to 'src/DotNetOpenAuth.AspNet/Clients/OAuth2/MicrosoftClient.cs')
-rw-r--r--src/DotNetOpenAuth.AspNet/Clients/OAuth2/MicrosoftClient.cs4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/DotNetOpenAuth.AspNet/Clients/OAuth2/MicrosoftClient.cs b/src/DotNetOpenAuth.AspNet/Clients/OAuth2/MicrosoftClient.cs
index d50f3c5..1fb219e 100644
--- a/src/DotNetOpenAuth.AspNet/Clients/OAuth2/MicrosoftClient.cs
+++ b/src/DotNetOpenAuth.AspNet/Clients/OAuth2/MicrosoftClient.cs
@@ -48,12 +48,12 @@ namespace DotNetOpenAuth.AspNet.Clients {
/// <summary>
/// Initializes a new instance of the <see cref="MicrosoftClient"/> class.
/// Requests a scope of "wl.signin" by default.
/// </summary>
/// <param name="appId">The app id.</param>
/// <param name="appSecret">The app secret.</param>
public MicrosoftClient(string appId, string appSecret)
- : this("microsoft", appId, appSecret, "wl.signin")
+ : this(appId, appSecret, "wl.basic")
{
}
@@ -48,12 +48,12 @@ namespace DotNetOpenAuth.AspNet.Clients {
/// <summary>
/// Initializes a new instance of the <see cref="MicrosoftClient"/> class.
- /// Requests a scope of "wl.signin" by default.
+ /// Requests a scope of "wl.basic" by default, but "wl.signin" is a good minimal alternative.
/// </summary>
/// <param name="appId">The app id.</param>